@@ -1,6 +1,6 @@
 package Courriel::Helpers;
-BEGIN {
-  $Courriel::Helpers::VERSION = '0.16';
+{
+  $Courriel::Helpers::VERSION = '0.17';
 }
 
 use strict;
@@ -27,10 +27,12 @@ sub fold_header {
 
     # Algorithm stolen from Email::Simple::Header
     while ($line) {
-        if ($line =~ s/^(.{0,76})(\s|\z)//) {
+        if ( $line =~ s/^(.{0,76})(\s|\z)// ) {
             $folded .= $1 . $CRLF;
             $folded .= q{  } if $line;
-        } else {
+        }
+        else {
+
             # Basically nothing we can do. :(
             $folded .= $line . $CRLF;
             last;
