@@ -1,6 +1,6 @@
 package Courriel::Types::Internal;
-BEGIN {
-  $Courriel::Types::Internal::VERSION = '0.16';
+{
+  $Courriel::Types::Internal::VERSION = '0.17';
 }
 
 use strict;
@@ -26,7 +26,7 @@ subtype Body,
     as role_type('Courriel::Role::Body');
 
 subtype Headers,
-    as role_type('Courriel::Role::Headers');
+    as class_type('Courriel::Headers');
 
 subtype EmailAddressStr,
     as NonEmptyStr;
